@@ -51,26 +51,27 @@ new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: Kin
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|kinesisFirehoseProps?|[`kinesisfirehose.CfnDeliveryStreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStreamProps.html)|Optional user provided props to override the default props for Kinesis Firehose Delivery Stream|
-|existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
-|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
+|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Bucket.|
+|createCloudWatchAlarms?|`boolean`|Optional whether to create recommended CloudWatch alarms.|
+|existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Optional existing instance of S3 Bucket object, if this is set then bucketProps and existingLoggingBucketObj are ignored.|
+|existingLoggingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Optional existing instance of logging S3 Bucket object for the S3 Bucket created by the pattern.|
+|existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
+|kinesisFirehoseProps?|[`kinesisfirehose.CfnDeliveryStreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStreamProps.html)|`any`|Optional user provided props to override the default props for Kinesis Firehose Delivery Stream.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
-|existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
-|createCloudWatchAlarms?|`boolean`|Whether to create recommended CloudWatch alarms|
-|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|Optional user provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|kinesisFirehose|[`kinesisfirehose.CfnDeliveryStream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStream.html)|Returns an instance of kinesisfirehose.CfnDeliveryStream created by the construct|
-|s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct|
-|s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
-|kinesisFirehoseRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis Data Firehose delivery stream|
-|kinesisFirehoseLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for Kinesis Data Firehose delivery stream|
-|kinesisStream|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Returns an instance of the Kinesis stream created by the pattern.|
-|kinesisStreamRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis stream.|
 |cloudwatchAlarms?|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
+|kinesisFirehose|[`kinesisfirehose.CfnDeliveryStream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStream.html)|Returns an instance of kinesisfirehose.CfnDeliveryStream created by the construct|
+|kinesisFirehoseLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the logs.LogGroup created by the construct for Kinesis Data Firehose delivery stream|
+|kinesisFirehoseRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis Data Firehose delivery stream|
+|kinesisStream|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Returns an instance of the Kinesis stream created by the pattern|
+|kinesisStreamRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis stream|
+|s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct|
+|s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket|
 
 ## Default settings
 
@@ -140,6 +141,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
@@ -148,13 +150,14 @@ class KinesisStreamsToKinesisFirehoseToS3(
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
-        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
-        :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
+        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param create_cloud_watch_alarms: Optional whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param existing_bucket_obj: Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored. Default: - None
+        :param existing_logging_bucket_obj: Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern. Default: - None
+        :param existing_stream_obj: Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
-        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
         :since: 1.68.0
@@ -164,6 +167,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
             bucket_props=bucket_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
             existing_bucket_obj=existing_bucket_obj,
+            existing_logging_bucket_obj=existing_logging_bucket_obj,
             existing_stream_obj=existing_stream_obj,
             kinesis_firehose_props=kinesis_firehose_props,
             kinesis_stream_props=kinesis_stream_props,
@@ -192,6 +196,11 @@ class KinesisStreamsToKinesisFirehoseToS3(
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="kinesisStreamRole")
+    def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
+        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisStreamRole"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
@@ -217,6 +226,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         "bucket_props": "bucketProps",
         "create_cloud_watch_alarms": "createCloudWatchAlarms",
         "existing_bucket_obj": "existingBucketObj",
+        "existing_logging_bucket_obj": "existingLoggingBucketObj",
         "existing_stream_obj": "existingStreamObj",
         "kinesis_firehose_props": "kinesisFirehoseProps",
         "kinesis_stream_props": "kinesisStreamProps",
@@ -230,6 +240,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
@@ -237,13 +248,14 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
     ) -> None:
         '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
 
-        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
-        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
-        :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
+        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param create_cloud_watch_alarms: Optional whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param existing_bucket_obj: Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored. Default: - None
+        :param existing_logging_bucket_obj: Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern. Default: - None
+        :param existing_stream_obj: Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
-        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
@@ -258,6 +270,8 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
         if existing_bucket_obj is not None:
             self._values["existing_bucket_obj"] = existing_bucket_obj
+        if existing_logging_bucket_obj is not None:
+            self._values["existing_logging_bucket_obj"] = existing_logging_bucket_obj
         if existing_stream_obj is not None:
             self._values["existing_stream_obj"] = existing_stream_obj
         if kinesis_firehose_props is not None:
@@ -269,7 +283,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        '''User provided props to override the default props for the S3 Bucket.
+        '''Optional user provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
         '''
@@ -278,7 +292,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
-        '''Whether to create recommended CloudWatch alarms.
+        '''Optional whether to create recommended CloudWatch alarms.
 
         :default: - Alarms are created
         '''
@@ -287,16 +301,25 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
-        '''Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
+        '''Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored.
 
         :default: - None
         '''
         result = self._values.get("existing_bucket_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
 
+    @builtins.property
+    def existing_logging_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+        '''Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern.
+
+        :default: - None
+        '''
+        result = self._values.get("existing_logging_bucket_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        '''Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
         :default: - None
         '''
@@ -323,7 +346,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
